AudioType enum

Represents the source type of the audio file.

Inheritance
Available extensions

Values

directFile → const AudioType

An audio file accessed directly from a file path.

assets → const AudioType

An audio file bundled within the app's assets.

url → const AudioType

An audio file accessed from a remote URL.

blobforWeb → const AudioType

An audio file stored as a Blob for web platforms.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AudioType>
A constant List of the values in this enum, in order of their declaration.