StyleTwoWidget class

A widget that represents the second player style.

Inheritance

Constructors

StyleTwoWidget({Key? key, required AudioPlayerWidget widget, required bool isPlaying, required double progress, required Duration position, required Duration duration, required Function playAudio, required Function pauseAudio, required dynamic seekTo(double), bool showTimer = true, bool showProgressBar = true, required bool showSpeedControl, required List<double> playbackSpeeds, required double currentSpeed, required dynamic setSpeed(double)})
Create a new instance of StyleTwoWidget.
const

Properties

currentSpeed → double
The callback function to seek to a specific position in the audio.
final
duration → Duration
The total duration of the audio.
final
hashCode → int
The hash code for this object.
no setterinherited
isPlaying → bool
Indicates whether the audio is currently playing.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
pauseAudio → Function
The callback function to pause the audio.
final
playAudio → Function
The callback function to play the audio.
final
playbackSpeeds → List<double>
The callback function to seek to a specific position in the audio.
final
position → Duration
The current position of the audio playback.
final
progress → double
The progress of the audio playback.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seekTo → dynamic Function(double)
The callback function to seek to a specific position in the audio.
final
setSpeed → dynamic Function(double)
The callback function to seek to a specific position in the audio.
final
showProgressBar → bool
Indicates whether to show the progress bar.
final
showSpeedControl → bool
The callback function to seek to a specific position in the audio.
final
showTimer → bool
Indicates whether to show the timer.
final
widget → AudioPlayerWidget
The main widget for the audio player.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited