VoiceNotePlayerController class

Controller for the audio player

Inheritance

Constructors

VoiceNotePlayerController()

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
bind({VoidCallback? play, VoidCallback? pause, void seek(double)?, void setSpeed(double)?}) → void
Binding internal player methods to this controller
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pause() → void
Calls the internal player callbacks pause
play() → void
Internal player methods Calls the internal player callbacks play
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
seekTo(double progress) → void
Calls the internal player callbacks seekTo
setSpeed(double speed) → void
Calls the internal player callbacks setSpeed
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited