VoiceRecorderWidget class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- VoiceRecorderWidget
Constructors
- VoiceRecorderWidget({Key? key, dynamic onRecorded(File file)?, dynamic onRecordedWeb(String url)?, dynamic onError(String url)?, dynamic onStartRecording()?, dynamic actionWhenCancel()?, dynamic onMaxDurationReached()?, Widget? startRecordingWidget, Widget? stopRecordingWidget, Duration? maxRecordDuration, double timerFontSize = 16, bool showSwipeLeftToCancel = true, bool showTimerText = true, bool enableHapticFeedback = true, Color backgroundColor = Colors.blueAccent, Color cancelHintColor = Colors.redAccent, Color iconColor = Colors.white, TextStyle? timerTextStyle, TextStyle? dragToLeftTextStyle, String cancelDoneText = 'Cancel Done', String permissionNotGrantedMessage = 'Permission not granted', String recordCancelledMessage = 'Record cancelled', String dragToLeftText = '← Drag to left to cancel', double iconSize = 56, String? startSoundAsset, String? stopSoundAsset, VoiceUIStyle? style = VoiceUIStyle.classic, Color? containerColor, Color? borderColor, double? borderRadius, Color? idleWavesColor = Colors.grey, Color? recordingWavesColor = Colors.blueAccent, Duration? wavesSpeed})
-
const
Properties
- actionWhenCancel → dynamic Function()?
-
final
- backgroundColor → Color
-
final
- borderColor → Color?
-
final
- borderRadius → double?
-
final
- cancelDoneText → String
-
final
- cancelHintColor → Color
-
final
- containerColor → Color?
-
final
- dragToLeftText → String
-
final
- dragToLeftTextStyle → TextStyle?
-
final
- enableHapticFeedback → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconColor → Color
-
final
- iconSize → double
-
final
- idleWavesColor → Color?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxRecordDuration → Duration?
-
final
- onError → dynamic Function(String url)?
-
final
- onMaxDurationReached → dynamic Function()?
-
final
- onRecorded → dynamic Function(File file)?
-
final
- onRecordedWeb → dynamic Function(String url)?
-
final
- onStartRecording → dynamic Function()?
-
final
- permissionNotGrantedMessage → String
-
final
- recordCancelledMessage → String
-
final
- recordingWavesColor → Color?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showSwipeLeftToCancel → bool
-
final
- showTimerText → bool
-
final
- startRecordingWidget → Widget?
-
final
- startSoundAsset → String?
-
final
- stopRecordingWidget → Widget?
-
final
- stopSoundAsset → String?
-
final
- style → VoiceUIStyle?
-
final
- timerFontSize → double
-
final
- timerTextStyle → TextStyle?
-
final
- wavesSpeed → Duration?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< VoiceRecorderWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited